; docformat = 'rst'
;+
; This is an example program to demonstrate how to create a multiple surface plot
; with Coyote Graphics routines. Instead of using !P.Multi to set up the multiplot,
; this program uses cgLayout, which is often much more flexible and powerful than
; !P.Multi.
;
; :Categories:
;    Graphics
;    
; :Examples:
;    Save the program as "multisurface_plot.pro" and run it like this::
;       IDL> .RUN multisurface_plot
;       
; :Author:
;    FANNING SOFTWARE CONSULTING::
;       David W. Fanning 
;       1645 Sheely Drive
;       Fort Collins, CO 80526 USA
;       Phone: 970-221-0438
;       E-mail: david@idlcoyote.com
;       Coyote's Guide to IDL Programming: http://www.idlcoyote.com
;
; :History:
;     Change History::
;        Written, 23 January 2013 by David W. Fanning.
;
; :Copyright:
;     Copyright (c) 2013, Fanning Software Consulting, Inc.
;-
PRO MultiSurface_Plot
 
   ; Set up variables for the plot. Normally, these values would be 
   ; passed into the program as positional and keyword parameters.
   data = cgDemoData(2)
   
   ; We want four plots in the window, with some room at the top of
   ; the four plots for title. The gap between rows should be larger
   ; to accommodate color bars for the lower surfaces.
   positions = cgLayout([2,2], OYMargin=[5,8], YGap=12)
   
   ; Load color tables.
   cgLoadCT, 5, /Brewer, /Reverse, RGB_Table=bluePalette
   cgLoadCT, 33, RGB_Table=rainbowPalette
   
   ; Normal surface plot.
   cgSurf, data, Position=positions[*,0], ROTX=60, ZCharsize=cgDefCharsize()*1.25
   
   ; Normal shaded surface plot.
   cgSurf, data, Position=positions[*,1], ROTX=60, ZCharsize=cgDefCharsize()*1.25, $
       /NoErase, /Shaded, Palette=bluePalette
   
   ; Elevation shaded surface plot with colorbar.
   cgSurf, data, Position=positions[*,2], ROTX=60, ZCharsize=cgDefCharsize()*1.25, $
       /NoErase, /Elevation, /Shaded, Palette=rainbowPalette
   p = [0.1, 0.40, 0.425, 0.42]
   cgColorbar, Palette=palette, Range=[Min(data),Max(data)], Position=p, $
      Charsize=cgDefCharsize()*0.75
   
   ; Shaded surface with elevation colors draped on top of it.
   cgSurf, data, Position=positions[*,3], ROTX=60, ZCharsize=cgDefCharsize()*1.25, $
      /NoErase, /Shaded, Palette=bluePalette
   cgSurf, data, Position=positions[*,3], ROTX=60, ZCharsize=cgDefCharsize()*1.25, $
      /NoErase, /Elevation, Palette=rainbowPalette
   p = [0.585, 0.40, 0.915, 0.42]
   cgColorbar, Palette=palette, Range=[Min(data),Max(data)], Position=p, $
      Charsize=cgDefCharsize()*0.75
   
   cgText, 0.5, 0.925, /Normal, 'Example Surface Plots', $
       Charsize=cgDefCharsize()*1.5, Alignment=0.5
       
END ;*****************************************************************

; This main program shows how to call the program and produce
; various types of output.

  ; Display the plot in a graphics window.
  MultiSurface_Plot
  
  ; Display the plot in a resizeable graphics window.
  cgWindow, 'MultiSurface_Plot', Background='White', $
     WTitle='Multiple Surface Plot in a Resizeable Graphics Window'
  
  ; Create a PostScript file.
  PS_Start, 'multisurface_plot.ps'
  MultiSurface_Plot
  PS_End
  
  ; Create a PNG file with a width of 600 pixels.
  cgPS2Raster, 'multisurface_plot.ps', /PNG, Width=600

END